==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkStructuredGridAppend.java <==
// java wrapper for vtkStructuredGridAppend object
//

package vtk;
import vtk.*;

public class vtkStructuredGridAppend extends vtkStructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReplaceNthInputConnection_2(int id0,vtkAlgorithmOutput id1);
  public void ReplaceNthInputConnection(int id0,vtkAlgorithmOutput id1)
    { ReplaceNthInputConnection_2(id0,id1); }

  private native void SetInputData_3(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_3(id0,id1); }

  private native void SetInputData_4(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_4(id0); }

  private native long GetInput_5(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_5(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long GetInput_6();
  public vtkDataObject GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfInputs_7();
  public int GetNumberOfInputs()
    { return GetNumberOfInputs_7(); }

  public vtkStructuredGridAppend() { super(); }

  public vtkStructuredGridAppend(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkStructuredGridAppend.java <==
// java wrapper for vtkStructuredGridAppend object
//

package vtk;
import vtk.*;

public class vtkStructuredGridAppend extends vtkStructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReplaceNthInputConnection_2(int id0,vtkAlgorithmOutput id1);
  public void ReplaceNthInputConnection(int id0,vtkAlgorithmOutput id1)
    { ReplaceNthInputConnection_2(id0,id1); }

  private native void SetInputData_3(int id0,vtkDataObject id1);
  public void SetInputData(int id0,vtkDataObject id1)
    { SetInputData_3(id0,id1); }

  private native void SetInputData_4(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_4(id0); }

  private native long GetInput_5(int id0);
  public vtkDataObject GetInput(int id0) {
    long temp = GetInput_5(id0);

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_6();
  public vtkDataObject GetInput() {
    long temp = GetInput_6();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfInputs_7();
  public int GetNumberOfInputs()
    { return GetNumberOfInputs_7(); }

  public vtkStructuredGridAppend() { super(); }

  public vtkStructuredGridAppend(long id) { super(id); }
  public native long   VTKInit();

}
